Index: branches/2.8.x/INSTALL
===================================================================
--- branches/2.8.x/INSTALL	(revision 1270)
+++ branches/2.8.x/INSTALL	(revision 1271)
@@ -1,7 +1,7 @@
-Website Baker 2 Installation Instructions
+WebsiteBaker 2 Installation Instructions
 ============================================
 This will quickly explain what you will need
-to install website baker.
+to install websiteBaker.
 
 First of all, you must have a webserver with
 PHP and MySQL installed correctly. Once you 
@@ -23,4 +23,4 @@
 
 Fill-out the form and submit it, and if all
 the details are correct, you should be taken
-to Website Baker Administration.
+to WebsiteBaker Administration.
Index: branches/2.8.x/CHANGELOG
===================================================================
--- branches/2.8.x/CHANGELOG	(revision 1270)
+++ branches/2.8.x/CHANGELOG	(revision 1271)
@@ -12,6 +12,8 @@
  
 ------------------------------------- 2.8.1 -------------------------------------
 22-Jan-2010 Dietmar Woellbrink (Luisehahne)
+!	continue update header info
+22-Jan-2010 Dietmar Woellbrink (Luisehahne)
 !	set svn keywords
 22-Jan-2010 Dietmar Woellbrink (Luisehahne)
 #	Ticket #869 Droplet-Engine does'nt work in some case
Index: branches/2.8.x/wb/upgrade-script.php
===================================================================
--- branches/2.8.x/wb/upgrade-script.php	(revision 1270)
+++ branches/2.8.x/wb/upgrade-script.php	(revision 1271)
@@ -39,8 +39,8 @@
  * @platform        WebsiteBaker 2.8.x
  * @requirements    PHP 4.3.4 and higher
  * @version         $Id$
- * @filesource		$HeadURL: $
- * @lastmodified    $Date: $
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
  *
  */
 

Property changes on: branches/2.8.x/wb/upgrade-script.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/admin/groups/groups.php
===================================================================
--- branches/2.8.x/wb/admin/groups/groups.php	(revision 1270)
+++ branches/2.8.x/wb/admin/groups/groups.php	(revision 1271)
@@ -30,7 +30,7 @@
 /**
  *
  * @category        admin
- * @package         group permission
+ * @package         groups
  * @author          WebsiteBaker Project
  * @copyright       2004-2009, Ryan Djurovich
  * @copyright       2009-2010, Website Baker Org. e.V.
Index: branches/2.8.x/wb/admin/groups/index.php
===================================================================
--- branches/2.8.x/wb/admin/groups/index.php	(revision 1270)
+++ branches/2.8.x/wb/admin/groups/index.php	(revision 1271)
@@ -30,7 +30,7 @@
 /**
  *
  * @category        admin
- * @package         permission
+ * @package         groups
  * @author          WebsiteBaker Project
  * @copyright       2004-2009, Ryan Djurovich
  * @copyright       2009-2010, Website Baker Org. e.V.
Index: branches/2.8.x/wb/admin/pages/settings.php
===================================================================
--- branches/2.8.x/wb/admin/pages/settings.php	(revision 1270)
+++ branches/2.8.x/wb/admin/pages/settings.php	(revision 1271)
@@ -1,28 +1,14 @@
 <?php
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -36,27 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-****************************************************************************
 *
-*****************************************************************************
 *                   WebsiteBaker Extra Information
 *
 *
-*
-*
-*****************************************************************************/
+*/
 /**
- * @category    admin
- * @package     pages
- * @author      Ryan Djurovich
- * @copyright   2004-2009, Ryan Djurovich
- * @copyright   2009, Website Baker Org. e.V.
- * @version     $Id$
- * @platform    WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license     http://www.gnu.org/licenses/gpl.html
  *
- */
+ * @category        admin
+ * @package         pages
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+*/
 
 // Get page id
 if(!isset($_GET['page_id']) OR !is_numeric($_GET['page_id'])) {

Property changes on: branches/2.8.x/wb/admin/pages/settings.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/admin/pages/modify.php
===================================================================
--- branches/2.8.x/wb/admin/pages/modify.php	(revision 1270)
+++ branches/2.8.x/wb/admin/pages/modify.php	(revision 1271)
@@ -1,28 +1,14 @@
 <?php
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -36,27 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-****************************************************************************
 *
-*****************************************************************************
 *                   WebsiteBaker Extra Information
 *
 *
-*
-*
-*****************************************************************************/
+*/
 /**
- * @category    admin
- * @package     pages
- * @author      Ryan Djurovich
- * @copyright   2004-2009, Ryan Djurovich
- * @copyright   2009-2010, Website Baker Org. e.V.
- * @version     $Id$
- * @platform    WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license     http://www.gnu.org/licenses/gpl.html
  *
- */
+ * @category        admin
+ * @package         pages
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+*/
 
 // Get page id
 if(!isset($_GET['page_id']) OR !is_numeric($_GET['page_id'])) {

Property changes on: branches/2.8.x/wb/admin/pages/modify.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/admin/interface/version.php
===================================================================
--- branches/2.8.x/wb/admin/interface/version.php	(revision 1270)
+++ branches/2.8.x/wb/admin/interface/version.php	(revision 1271)
@@ -52,6 +52,6 @@
 
 // check if defined to avoid errors during installation (redirect to admin panel fails if PHP error/warnings are enabled)
 if(!defined('VERSION')) define('VERSION', '2.8.1');
-if(!defined('REVISION')) define('REVISION', '1270');
+if(!defined('REVISION')) define('REVISION', '1271');
 
 ?>
\ No newline at end of file
Index: branches/2.8.x/wb/admin/users/users.php
===================================================================
--- branches/2.8.x/wb/admin/users/users.php	(revision 1270)
+++ branches/2.8.x/wb/admin/users/users.php	(revision 1271)
@@ -1,28 +1,14 @@
 <?php
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -36,27 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-****************************************************************************
 *
-*****************************************************************************
 *                   WebsiteBaker Extra Information
 *
 *
-*
-*
-*****************************************************************************/
+*/
 /**
- * @category    admin
- * @package     users
- * @author      Ryan Djurovich
- * @copyright   2004-2009, Ryan Djurovich
- * @copyright   2009-2010, Website Baker Org. e.V.
- * @version     $Id$
- * @platform    WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license     http://www.gnu.org/licenses/gpl.html
  *
- */
+ * @category        admin
+ * @package         users
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+*/
 
  // Include config file and admin class file
 require('../../config.php');

Property changes on: branches/2.8.x/wb/admin/users/users.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/admin/users/index.php
===================================================================
--- branches/2.8.x/wb/admin/users/index.php	(revision 1270)
+++ branches/2.8.x/wb/admin/users/index.php	(revision 1271)
@@ -1,28 +1,14 @@
 <?php
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -36,27 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-****************************************************************************
 *
-*****************************************************************************
 *                   WebsiteBaker Extra Information
 *
 *
-*
-*
-*****************************************************************************/
+*/
 /**
- * @category    admin
- * @package     users
- * @author      Ryan Djurovich
- * @copyright   2004-2009, Ryan Djurovich
- * @copyright   2009-2010, Website Baker Org. e.V.
- * @version     $Id$ 
- * @platform    WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license     http://www.gnu.org/licenses/gpl.html
  *
- */
+ * @category        admin
+ * @package         users
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+*/
 
 
 require('../../config.php');

Property changes on: branches/2.8.x/wb/admin/users/index.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/admin/login/forgot/index.php
===================================================================
--- branches/2.8.x/wb/admin/login/forgot/index.php	(revision 1270)
+++ branches/2.8.x/wb/admin/login/forgot/index.php	(revision 1271)
@@ -1,28 +1,14 @@
 <?php
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -36,27 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-****************************************************************************
 *
-*****************************************************************************
 *                   WebsiteBaker Extra Information
 *
 *
-*
-*
-*****************************************************************************/
+*/
 /**
- * @category    admin
- * @package     login
- * @author      Ryan Djurovich
- * @copyright   2004-2009, Ryan Djurovich
- * @copyright   2009-2010, Website Baker Org. e.V.
- * @version     $Id$
- * @platform    WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license     http://www.gnu.org/licenses/gpl.html
  *
- */
+ * @category        admin
+ * @package         login
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+*/
 
 // Include the configuration file
 require('../../../config.php');

Property changes on: branches/2.8.x/wb/admin/login/forgot/index.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/framework/class.admin.php
===================================================================
--- branches/2.8.x/wb/framework/class.admin.php	(revision 1270)
+++ branches/2.8.x/wb/framework/class.admin.php	(revision 1271)
@@ -39,8 +39,8 @@
  * @platform        WebsiteBaker 2.8.x
  * @requirements    PHP 4.3.4 and higher
  * @version         $Id$
- * @filesource		$HeadURL:  $
- * @lastmodified    $Date: $
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
  *
  */
 

Property changes on: branches/2.8.x/wb/framework/class.admin.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/modules/backup/languages/NL.php
===================================================================
--- branches/2.8.x/wb/modules/backup/languages/NL.php	(revision 1270)
+++ branches/2.8.x/wb/modules/backup/languages/NL.php	(revision 1271)
@@ -1,38 +1,14 @@
 <?php
-
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                   WebsiteBaker Extra Information (where needed)
-*
-*  DUTCH LANGUAGE FILE FOR THE ADDON: BACKUP
-*
-*****************************************************************************
-*
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -46,7 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*****************************************************************************/
+*
+*                   WebsiteBaker Extra Information
+*
+*
+*/
+/**
+ *
+ * @category        modules
+ * @package         backup
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+*/
 
 // text outputs
 $MOD_BACKUP['BACKUP_ALL_TABLES'] 	= 	'Backup van alle tabellen in de database';

Property changes on: branches/2.8.x/wb/modules/backup/languages/NL.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/modules/backup/languages/NO.php
===================================================================
--- branches/2.8.x/wb/modules/backup/languages/NO.php	(revision 1270)
+++ branches/2.8.x/wb/modules/backup/languages/NO.php	(revision 1271)
@@ -1,38 +1,14 @@
 <?php
-
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                   WebsiteBaker Extra Information (where needed)
-*
-*  NORWEGIAN LANGUAGE FILE FOR THE ADDON: BACKUP
-*
-*****************************************************************************
-*
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -46,7 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*****************************************************************************/
+*
+*                   WebsiteBaker Extra Information
+*
+*
+*/
+/**
+ *
+ * @category        modules
+ * @package         backup
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+*/
 
 // text outputs
 $MOD_BACKUP['BACKUP_ALL_TABLES']	='Sikkerhetskopier alle tabellene i databsen';

Property changes on: branches/2.8.x/wb/modules/backup/languages/NO.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/modules/backup/languages/EN.php
===================================================================
--- branches/2.8.x/wb/modules/backup/languages/EN.php	(revision 1270)
+++ branches/2.8.x/wb/modules/backup/languages/EN.php	(revision 1271)
@@ -1,38 +1,14 @@
 <?php
-
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                   WebsiteBaker Extra Information (where needed)
-*
-*  ENGLISH LANGUAGE FILE FOR THE ADDON: BACKUP
-*
-*****************************************************************************
-*
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -46,7 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*****************************************************************************/
+*
+*                   WebsiteBaker Extra Information
+*
+*
+*/
+/**
+ *
+ * @category        modules
+ * @package         backup
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+*/
 
 // text outputs
 $MOD_BACKUP['BACKUP_ALL_TABLES'] 	= 	'Backup all tables in database';

Property changes on: branches/2.8.x/wb/modules/backup/languages/EN.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/modules/backup/languages/DA.php
===================================================================
--- branches/2.8.x/wb/modules/backup/languages/DA.php	(revision 1270)
+++ branches/2.8.x/wb/modules/backup/languages/DA.php	(revision 1271)
@@ -1,38 +1,14 @@
 <?php
-
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                   WebsiteBaker Extra Information (where needed)
-*
-*  DANISH LANGUAGE FILE FOR THE ADDON: BACKUP
-*
-*****************************************************************************
-*
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -46,7 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*****************************************************************************/
+*
+*                   WebsiteBaker Extra Information
+*
+*
+*/
+/**
+ *
+ * @category        modules
+ * @package         backup
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+*/
 
 // text outputs
 $MOD_BACKUP['BACKUP_ALL_TABLES'] = 'Tag backup af alle tabeller i databasen';

Property changes on: branches/2.8.x/wb/modules/backup/languages/DA.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/modules/backup/languages/RU.php
===================================================================
--- branches/2.8.x/wb/modules/backup/languages/RU.php	(revision 1270)
+++ branches/2.8.x/wb/modules/backup/languages/RU.php	(revision 1271)
@@ -1,38 +1,14 @@
 <?php
-
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                   WebsiteBaker Extra Information (where needed)
-*
-* RUSSIAN LANGUAGE FILE FOR THE ADDON: BACKUP
-*
-*****************************************************************************
-*
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -46,7 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*****************************************************************************/
+*
+*                   WebsiteBaker Extra Information
+*
+*
+*/
+/**
+ *
+ * @category        modules
+ * @package         backup
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+*/
 
 // text outputs
 $MOD_BACKUP['BACKUP_ALL_TABLES'] 	= 	'Backup &#1074;&#1089;&#1077;&#1093; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094; &#1073;&#1072;&#1079;&#1099;';

Property changes on: branches/2.8.x/wb/modules/backup/languages/RU.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/modules/backup/languages/FR.php
===================================================================
--- branches/2.8.x/wb/modules/backup/languages/FR.php	(revision 1270)
+++ branches/2.8.x/wb/modules/backup/languages/FR.php	(revision 1271)
@@ -1,38 +1,14 @@
 <?php
-
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                   WebsiteBaker Extra Information (where needed)
-*
-*  FRENCH LANGUAGE FILE FOR THE ADDON: BACKUP
-*
-*****************************************************************************
-*
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -46,7 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*****************************************************************************/
+*
+*                   WebsiteBaker Extra Information
+*
+*
+*/
+/**
+ *
+ * @category        modules
+ * @package         backup
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+*/
 
 //Module Description
 $module_description = 'Ce module permets de sauvegarder votre base de donn&eacute;es';

Property changes on: branches/2.8.x/wb/modules/backup/languages/FR.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/modules/backup/languages/index.php
===================================================================
--- branches/2.8.x/wb/modules/backup/languages/index.php	(revision 1270)
+++ branches/2.8.x/wb/modules/backup/languages/index.php	(revision 1271)
@@ -1,38 +1,14 @@
 <?php
-
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                   WebsiteBaker Extra Information (where needed)
-*
-*
-*
-*****************************************************************************
-*
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -46,7 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*****************************************************************************/
+*
+*                   WebsiteBaker Extra Information
+*
+*
+*/
+/**
+ *
+ * @category        modules
+ * @package         backup
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+*/
 
 header("Location: ../../../index.php");
 

Property changes on: branches/2.8.x/wb/modules/backup/languages/index.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/wb/modules/backup/languages/DE.php
===================================================================
--- branches/2.8.x/wb/modules/backup/languages/DE.php	(revision 1270)
+++ branches/2.8.x/wb/modules/backup/languages/DE.php	(revision 1271)
@@ -1,38 +1,14 @@
 <?php
-
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                   WebsiteBaker Extra Information (where needed)
-*
-* DEUTSCHE SPRACHDATEI FUER DAS MODUL: BACKUP
-*
-*****************************************************************************
-*
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -46,7 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*****************************************************************************/
+*
+*                   WebsiteBaker Extra Information
+*
+*
+*/
+/**
+ *
+ * @category        modules
+ * @package         backup
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
+*/
 
 // Deutsche Modulbeschreibung
 $module_description = 'Dieses Modul erm&ouml;glicht die Erstellung einer Datenbanksicherung.';

Property changes on: branches/2.8.x/wb/modules/backup/languages/DE.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
Index: branches/2.8.x/README
===================================================================
--- branches/2.8.x/README	(revision 1270)
+++ branches/2.8.x/README	(revision 1271)
@@ -1,46 +1,45 @@
 General Information
 ===================
-Website Baker is a PHP-based content management system
+WebsiteBaker is a PHP-based content management system
 which enables users to produce websites with ease.
 Features include a template-based front-end, modulated
 and multi-level page support, multi-user administration,
 and much much more!
 
-
 License
 =======
-Website Baker is released under the GNU General Public License,
+WebsiteBaker is released under the GNU General Public License,
 Copyright (C) 2004-2009 Ryan Djurovich.
+Copyright (C) 2009-2010 Website Baker Org. e.V.
 Please refer to the COPYING file for a copy of the license.
 
-
 Installation
 ============
 Please refer to the INSTALL file for instructions on installation.
 
-
 Usage
 =====
-Before using Website Baker please note: you must not remove/change any
+Before using WebsiteBaker please note: you must not remove/change any
 copyright notices in the any code contained in this package.
 Also, it is appreciated if you leave a link somewhere on your website,
-which links to the Website Baker website. (http://www.websitebaker.org/) 
+which links to the WebsiteBaker website. (http://www.websitebaker2.org/) 
 
-
 Support
 =======
 For information about finding help:
-http://www.websitebaker.org
+http://www.websitebaker2.org/
 
+Community
+=========
+For more information about finding help:
+http://forum.websitebaker2.org/
 
 Bugs
 ====
 To submit a bug:
-http://www.websitebaker.org
+http://project.websitebaker2.org/
 
-
 Contribute
 ==========
 For information about how to contribute (donating, etc):
-http://www.websitebaker.org
-
+http://www.websitebaker2.org

Index: branches/2.8.x/wb/admin/start/index.php
===================================================================
--- branches/2.8.x/wb/admin/start/index.php	(revision 1270)
+++ branches/2.8.x/wb/admin/start/index.php	(revision 1271)
@@ -1,28 +1,14 @@
 <?php
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -36,27 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-****************************************************************************
 *
 *                   WebsiteBaker Extra Information
 *
 *
-*
-*
-*****************************************************************************/
+*/
 /**
  *
  * @category     admin
  * @package      start
  * @author       Ryan Djurovich
  * @copyright    2004-2009, Ryan Djurovich
  * @copyright    2009-2010, Website Baker Org. e.V.
  * @version      $Id$
  * @platform     WebsiteBaker 2.8.x
  * @requirements >= PHP 4.3.4
  * @license      http://www.gnu.org/licenses/gpl.html
  *
- */
+*/
 
 require('../../config.php');
 require_once(WB_PATH.'/framework/class.admin.php');

Property changes on: branches/2.8.x/wb/admin/start/index.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
@@ -36,27 +22,27 @@
 /**
  *
- * @category     admin
- * @package      start
- * @author       Ryan Djurovich
- * @copyright    2004-2009, Ryan Djurovich
- * @copyright    2009-2010, Website Baker Org. e.V.
- * @version      $Id$
- * @platform     WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license      http://www.gnu.org/licenses/gpl.html
+ * @category        admin
+ * @package         start
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
  *
Index: branches/2.8.x/wb/modules/menu_link/save.php
===================================================================
--- branches/2.8.x/wb/modules/menu_link/save.php	(revision 1270)
+++ branches/2.8.x/wb/modules/menu_link/save.php	(revision 1271)
@@ -1,29 +1,14 @@
 <?php
-/***************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -37,30 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-****************************************************************************
 *
-*****************************************************************************
 *                   WebsiteBaker Extra Information
 *
 *
-*
-*
-*****************************************************************************/
-
+*/
 /**
  *
  * @category     modules
  * @package      menu_link
  * @author       Ryan Djurovich
  * @copyright    2004-2009, Ryan Djurovich
  * @copyright    2009, Website Baker Org. e.V.
  * @version      $Id$
  * @platform     WebsiteBaker 2.8.x
  * @requirements >= PHP 4.3.4
  * @license      http://www.gnu.org/licenses/gpl.html
  *
- *
- */
+*/
 
 require_once('../../config.php');
 

Property changes on: branches/2.8.x/wb/modules/menu_link/save.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
@@ -37,30 +22,27 @@
 /**
  *
- * @category     modules
- * @package      menu_link
- * @author       Ryan Djurovich
- * @copyright    2004-2009, Ryan Djurovich
- * @copyright    2009, Website Baker Org. e.V.
- * @version      $Id$
- * @platform     WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license      http://www.gnu.org/licenses/gpl.html
+ * @category        modules
+ * @package         menu_link
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
  *
Index: branches/2.8.x/wb/modules/menu_link/index.php
===================================================================
--- branches/2.8.x/wb/modules/menu_link/index.php	(revision 1270)
+++ branches/2.8.x/wb/modules/menu_link/index.php	(revision 1271)
@@ -1,28 +1,14 @@
 <?php
-/***************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -36,29 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-****************************************************************************
 *
-*****************************************************************************
 *                   WebsiteBaker Extra Information
 *
 *
-*
-*
-*****************************************************************************/
+*/
 /**
  *
  * @category     modules
  * @package      menu_link
  * @author       Ryan Djurovich
  * @copyright    2004-2009, Ryan Djurovich
  * @copyright    2009, Website Baker Org. e.V.
  * @version      $Id$
  * @platform     WebsiteBaker 2.8.x
  * @requirements >= PHP 4.3.4
  * @license      http://www.gnu.org/licenses/gpl.html
  *
- *
- */
+*/
 
 header('Location: ../index.php');
 

Property changes on: branches/2.8.x/wb/modules/menu_link/index.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
@@ -36,29 +22,27 @@
 /**
  *
- * @category     modules
- * @package      menu_link
- * @author       Ryan Djurovich
- * @copyright    2004-2009, Ryan Djurovich
- * @copyright    2009, Website Baker Org. e.V.
- * @version      $Id$
- * @platform     WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license      http://www.gnu.org/licenses/gpl.html
+ * @category        modules
+ * @package         menu_link
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
  *
Index: branches/2.8.x/wb/modules/menu_link/modify.php
===================================================================
--- branches/2.8.x/wb/modules/menu_link/modify.php	(revision 1270)
+++ branches/2.8.x/wb/modules/menu_link/modify.php	(revision 1271)
@@ -1,28 +1,14 @@
 <?php
-/***************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -36,30 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-****************************************************************************
 *
-*****************************************************************************
 *                   WebsiteBaker Extra Information
 *
 *
-*
-*
-*****************************************************************************/
-
+*/
 /**
  *
  * @category     modules
  * @package      menu_link
  * @author       Ryan Djurovich
  * @copyright    2004-2009, Ryan Djurovich
  * @copyright    2009, Website Baker Org. e.V.
  * @version      $Id$
  * @platform     WebsiteBaker 2.8.x
  * @requirements >= PHP 4.3.4
  * @license      http://www.gnu.org/licenses/gpl.html
  *
- *
- */
+*/
 
 // Must include code to stop this file being accessed directly
 if(defined('WB_PATH') == false) { exit("Cannot access this file directly"); }

Property changes on: branches/2.8.x/wb/modules/menu_link/modify.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
@@ -36,30 +22,27 @@
 /**
  *
- * @category     modules
- * @package      menu_link
- * @author       Ryan Djurovich
- * @copyright    2004-2009, Ryan Djurovich
- * @copyright    2009, Website Baker Org. e.V.
- * @version      $Id$
- * @platform     WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license      http://www.gnu.org/licenses/gpl.html
+ * @category        modules
+ * @package         menu_link
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
  *
Index: branches/2.8.x/wb/modules/wysiwyg/save.php
===================================================================
--- branches/2.8.x/wb/modules/wysiwyg/save.php	(revision 1270)
+++ branches/2.8.x/wb/modules/wysiwyg/save.php	(revision 1271)
@@ -1,28 +1,14 @@
 <?php
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -36,27 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-****************************************************************************
 *
 *                   WebsiteBaker Extra Information
 *
 *
-*
-*
-*****************************************************************************/
+*/
 /**
  *
  * @category     backend
  * @package      wysiwyg
  * @author       Ryan Djurovich
  * @copyright    2004-2009, Ryan Djurovich
  * @copyright    2009, Website Baker Org. e.V.
  * @version      $Id$
  * @platform     WebsiteBaker 2.8.x
  * @requirements >= PHP 4.3.4
  * @license      http://www.gnu.org/licenses/gpl.html
  *
- */
+*/
 
 require('../../config.php');
 

Property changes on: branches/2.8.x/wb/modules/wysiwyg/save.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
@@ -36,27 +22,27 @@
 /**
  *
- * @category     backend
- * @package      wysiwyg
- * @author       Ryan Djurovich
- * @copyright    2004-2009, Ryan Djurovich
- * @copyright    2009, Website Baker Org. e.V.
- * @version      $Id$
- * @platform     WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license      http://www.gnu.org/licenses/gpl.html
+ * @category        backend
+ * @package         wysiwyg
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
  *
Index: branches/2.8.x/wb/modules/captcha_control/languages/SK.php
===================================================================
--- branches/2.8.x/wb/modules/captcha_control/languages/SK.php	(revision 1270)
+++ branches/2.8.x/wb/modules/captcha_control/languages/SK.php	(revision 1271)
@@ -1,30 +1,14 @@
 <?php
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*
-*
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -38,30 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-****************************************************************************
 *
 *                   WebsiteBaker Extra Information
 *
 *
-*
-*
-*
-*
-*
-*****************************************************************************/
+*/
 /**
  *
  * @category     frontend
  * @package      framework
  * @author       Ryan Djurovich
  * @copyright    2004-2009, Ryan Djurovich
  * @copyright    2009-2010, Website Baker Org. e.V.
  * @version      $Id$
  * @platform     WebsiteBaker 2.8.x
  * @requirements >= PHP 4.3.4
  * @license      http://www.gnu.org/licenses/gpl.html
  *
- */
+*/
 
 // Headings and text outputs
 $MOD_CAPTCHA_CONTROL['HEADING']           = 'Captcha a ASP kontrola';

Property changes on: branches/2.8.x/wb/modules/captcha_control/languages/SK.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
@@ -38,30 +22,27 @@
 /**
  *
- * @category     frontend
- * @package      framework
- * @author       Ryan Djurovich
- * @copyright    2004-2009, Ryan Djurovich
- * @copyright    2009-2010, Website Baker Org. e.V.
- * @version      $Id$
- * @platform     WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license      http://www.gnu.org/licenses/gpl.html
+ * @category        backend
+ * @package         languages
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
  *
Index: branches/2.8.x/wb/modules/backup/info.php
===================================================================
--- branches/2.8.x/wb/modules/backup/info.php	(revision 1270)
+++ branches/2.8.x/wb/modules/backup/info.php	(revision 1271)
@@ -1,37 +1,14 @@
 <?php
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                   WebsiteBaker Extra Information (where needed)
-*
-*
-*
-*****************************************************************************
-*
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -45,21 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*****************************************************************************/
+*
+*                   WebsiteBaker Extra Information
+*
+*
+*/
 /**
  *
  * @category     modules
  * @package      backup
  * @author       Ryan Djurovich
  * @copyright    2004-2009, Ryan Djurovich
  * @copyright    2009, Website Baker Org. e.V.
  * @version      $Id$
  * @platform     WebsiteBaker 2.8.x
  * @requirements >= PHP 4.3.4
  * @license      http://www.gnu.org/licenses/gpl.html
  *
- *
- */
+*/
 
 $module_directory = 'backup';
 $module_name = 'Backup';

Property changes on: branches/2.8.x/wb/modules/backup/info.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
@@ -45,21 +22,27 @@
 /**
  *
- * @category     modules
- * @package      backup
- * @author       Ryan Djurovich
- * @copyright    2004-2009, Ryan Djurovich
- * @copyright    2009, Website Baker Org. e.V.
- * @version      $Id$
- * @platform     WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license      http://www.gnu.org/licenses/gpl.html
+ * @category        modules
+ * @package         backup
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
  *
Index: branches/2.8.x/wb/modules/backup/tool.php
===================================================================
--- branches/2.8.x/wb/modules/backup/tool.php	(revision 1270)
+++ branches/2.8.x/wb/modules/backup/tool.php	(revision 1271)
@@ -1,38 +1,14 @@
 <?php
-
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                   WebsiteBaker Extra Information (where needed)
-*
-*
-*
-*****************************************************************************
-*
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -46,21 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*****************************************************************************/
+*
+*                   WebsiteBaker Extra Information
+*
+*
+*/
 /**
  *
  * @category     modules
  * @package      backup
  * @author       Ryan Djurovich
  * @copyright    2004-2009, Ryan Djurovich
  * @copyright    2009, Website Baker Org. e.V.
  * @version      $Id$
  * @platform     WebsiteBaker 2.8.x
  * @requirements >= PHP 4.3.4
  * @license      http://www.gnu.org/licenses/gpl.html
  *
- *
- */
+*/
 
 // Direct access prevention
 defined('WB_PATH') OR die(header('Location: ../index.php'));

Property changes on: branches/2.8.x/wb/modules/backup/tool.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
@@ -46,21 +22,27 @@
 /**
  *
- * @category     modules
- * @package      backup
- * @author       Ryan Djurovich
- * @copyright    2004-2009, Ryan Djurovich
- * @copyright    2009, Website Baker Org. e.V.
- * @version      $Id$
- * @platform     WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license      http://www.gnu.org/licenses/gpl.html
+ * @category        modules
+ * @package         backup
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
  *
Index: branches/2.8.x/wb/modules/backup/backup-sql.php
===================================================================
--- branches/2.8.x/wb/modules/backup/backup-sql.php	(revision 1270)
+++ branches/2.8.x/wb/modules/backup/backup-sql.php	(revision 1271)
@@ -1,37 +1,14 @@
 <?php
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                   WebsiteBaker Extra Information (where needed)
-*
-*
-*
-*****************************************************************************
-*
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -45,21 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*****************************************************************************/
+*
+*                   WebsiteBaker Extra Information
+*
+*
+*/
 /**
  *
  * @category     modules
  * @package      backup
  * @author       Ryan Djurovich
  * @copyright    2004-2009, Ryan Djurovich
  * @copyright    2009, Website Baker Org. e.V.
  * @version      $Id$
  * @platform     WebsiteBaker 2.8.x
  * @requirements >= PHP 4.3.4
  * @license      http://www.gnu.org/licenses/gpl.html
  *
- *
- */
+*/
 
 // Filename to use
 $filename = $_SERVER['HTTP_HOST'].'-backup-'.gmdate('Y-m-d', time()+TIMEZONE).'.sql';

Property changes on: branches/2.8.x/wb/modules/backup/backup-sql.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
@@ -45,21 +22,27 @@
 /**
  *
- * @category     modules
- * @package      backup
- * @author       Ryan Djurovich
- * @copyright    2004-2009, Ryan Djurovich
- * @copyright    2009, Website Baker Org. e.V.
- * @version      $Id$
- * @platform     WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license      http://www.gnu.org/licenses/gpl.html
+ * @category        modules
+ * @package         backup
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
  *
Index: branches/2.8.x/wb/modules/backup/index.php
===================================================================
--- branches/2.8.x/wb/modules/backup/index.php	(revision 1270)
+++ branches/2.8.x/wb/modules/backup/index.php	(revision 1271)
@@ -1,28 +1,14 @@
 <?php
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -36,28 +22,26 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-****************************************************************************
 *
-*****************************************************************************
 *                   WebsiteBaker Extra Information
 *
 *
-*
-*
-*****************************************************************************/
+*/
 /**
 *
 * @category     modules
 * @package      backup
 * @author       Ryan Djurovich
 * @copyright    2004-2009, Ryan Djurovich
 * @copyright    2009, Website Baker Org. e.V.
 * @version      $Id$
 * @platform     WebsiteBaker 2.8.x
 * @requirements >= PHP 4.3.4
 * @license      http://www.gnu.org/licenses/gpl.html
 *
 *
 */
 
 header('Location: ../index.php');

Property changes on: branches/2.8.x/wb/modules/backup/index.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
@@ -36,28 +22,26 @@
 /**
-*
-* @category     modules
-* @package      backup
-* @author       Ryan Djurovich
-* @copyright    2004-2009, Ryan Djurovich
-* @copyright    2009, Website Baker Org. e.V.
-* @version      $Id$
-* @platform     WebsiteBaker 2.8.x
-* @requirements >= PHP 4.3.4
-* @license      http://www.gnu.org/licenses/gpl.html
-*
-*
+ *
+ * @category        modules
+ * @package         backup
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
+ *
 */
 
Index: branches/2.8.x/wb/modules/code/info.php
===================================================================
--- branches/2.8.x/wb/modules/code/info.php	(revision 1270)
+++ branches/2.8.x/wb/modules/code/info.php	(revision 1271)
@@ -1,27 +1,13 @@
 <?php
-/***************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
-
-*****************************************************************************
-*                        LICENSE INFORMATION
+*                       LICENSE INFORMATION
 *
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
@@ -36,29 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-****************************************************************************
-
-*****************************************************************************
+*
 *                   WebsiteBaker Extra Information
 *
 *
-*
-*
-*****************************************************************************/
+*/
 /**
  *
  * @category     modules
  * @package      code
  * @author       Ryan Djurovich
  * @copyright    2004-2009, Ryan Djurovich
  * @copyright    2009, Website Baker Org. e.V.
  * @version      $Id$
  * @platform     WebsiteBaker 2.8.x
  * @requirements >= PHP 4.3.4
  * @license      http://www.gnu.org/licenses/gpl.html
  *
- *
- */
+*/
 
 $module_directory	= 'code';
 $module_name		= 'Code';

Property changes on: branches/2.8.x/wb/modules/code/info.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
@@ -36,29 +22,27 @@
 /**
  *
- * @category     modules
- * @package      code
- * @author       Ryan Djurovich
- * @copyright    2004-2009, Ryan Djurovich
- * @copyright    2009, Website Baker Org. e.V.
- * @version      $Id$
- * @platform     WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license      http://www.gnu.org/licenses/gpl.html
+ * @category        modules
+ * @package         code
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
  *
Index: branches/2.8.x/wb/modules/code/save.php
===================================================================
--- branches/2.8.x/wb/modules/code/save.php	(revision 1270)
+++ branches/2.8.x/wb/modules/code/save.php	(revision 1271)
@@ -1,27 +1,13 @@
 <?php
-/***************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
-
-*****************************************************************************
-*                        LICENSE INFORMATION
+*                       LICENSE INFORMATION
 *
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
@@ -36,29 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-****************************************************************************
-
-*****************************************************************************
+*
 *                   WebsiteBaker Extra Information
 *
 *
-*
-*
-*****************************************************************************/
+*/
 /**
  *
  * @category     modules
  * @package      code
  * @author       Ryan Djurovich
  * @copyright    2004-2009, Ryan Djurovich
  * @copyright    2009, Website Baker Org. e.V.
  * @version      $Id$
  * @platform     WebsiteBaker 2.8.x
  * @requirements >= PHP 4.3.4
  * @license      http://www.gnu.org/licenses/gpl.html
  *
- *
- */
+*/
 
 require('../../config.php');
 

Property changes on: branches/2.8.x/wb/modules/code/save.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
@@ -36,29 +22,27 @@
 /**
  *
- * @category     modules
- * @package      code
- * @author       Ryan Djurovich
- * @copyright    2004-2009, Ryan Djurovich
- * @copyright    2009, Website Baker Org. e.V.
- * @version      $Id$
- * @platform     WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license      http://www.gnu.org/licenses/gpl.html
+ * @category        modules
+ * @package         code
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
  *
Index: branches/2.8.x/wb/modules/code/index.php
===================================================================
--- branches/2.8.x/wb/modules/code/index.php	(revision 1270)
+++ branches/2.8.x/wb/modules/code/index.php	(revision 1271)
@@ -1,27 +1,13 @@
 <?php
-/***************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
-
-*****************************************************************************
-*                        LICENSE INFORMATION
+*                       LICENSE INFORMATION
 *
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
@@ -36,28 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-****************************************************************************
 *
 *                   WebsiteBaker Extra Information
 *
 *
-*
-*
-*****************************************************************************/
+*/
 /**
  *
  * @category     modules
  * @package      code
  * @author       Ryan Djurovich
  * @copyright    2004-2009, Ryan Djurovich
  * @copyright    2009, Website Baker Org. e.V.
  * @version      $Id$
  * @platform     WebsiteBaker 2.8.x
  * @requirements >= PHP 4.3.4
  * @license      http://www.gnu.org/licenses/gpl.html
  *
- *
- */
+*/
 
 header('Location: ../index.php');
 

Property changes on: branches/2.8.x/wb/modules/code/index.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
@@ -36,28 +22,27 @@
 /**
  *
- * @category     modules
- * @package      code
- * @author       Ryan Djurovich
- * @copyright    2004-2009, Ryan Djurovich
- * @copyright    2009, Website Baker Org. e.V.
- * @version      $Id$
- * @platform     WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license      http://www.gnu.org/licenses/gpl.html
+ * @category        modules
+ * @package         code
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
  *
Index: branches/2.8.x/wb/modules/code/modify.php
===================================================================
--- branches/2.8.x/wb/modules/code/modify.php	(revision 1270)
+++ branches/2.8.x/wb/modules/code/modify.php	(revision 1271)
@@ -1,27 +1,13 @@
 <?php
-/***************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
-
-*****************************************************************************
-*                        LICENSE INFORMATION
+*                       LICENSE INFORMATION
 *
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
@@ -36,29 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-****************************************************************************
-
-*****************************************************************************
+*
 *                   WebsiteBaker Extra Information
 *
 *
-*
-*
-*****************************************************************************/
+*/
 /**
  *
  * @category     modules
  * @package      code
  * @author       Ryan Djurovich
  * @copyright    2004-2009, Ryan Djurovich
  * @copyright    2009, Website Baker Org. e.V.
  * @version      $Id$
  * @platform     WebsiteBaker 2.8.x
  * @requirements >= PHP 4.3.4
  * @license      http://www.gnu.org/licenses/gpl.html
  *
- *
- */
+*/
 
 // Setup template object
 $template = new Template(WB_PATH.'/modules/code');

Property changes on: branches/2.8.x/wb/modules/code/modify.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
@@ -36,29 +22,27 @@
 /**
  *
- * @category     modules
- * @package      code
- * @author       Ryan Djurovich
- * @copyright    2004-2009, Ryan Djurovich
- * @copyright    2009, Website Baker Org. e.V.
- * @version      $Id$
- * @platform     WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license      http://www.gnu.org/licenses/gpl.html
+ * @category        modules
+ * @package         code
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
  *
Index: branches/2.8.x/wb/modules/fckeditor/include.php
===================================================================
--- branches/2.8.x/wb/modules/fckeditor/include.php	(revision 1270)
+++ branches/2.8.x/wb/modules/fckeditor/include.php	(revision 1271)
@@ -1,28 +1,14 @@
 <?php
-/****************************************************************************
-* SVN Version information:
+/*
 *
-* $Id$
+*                       About WebsiteBaker
 *
-*****************************************************************************
-*                          WebsiteBaker
-*
-* WebsiteBaker Project <http://www.websitebaker2.org/>
-* Copyright (C) 2009, Website Baker Org. e.V.
-*         http://start.websitebaker2.org/impressum-datenschutz.php
-* Copyright (C) 2004-2009, Ryan Djurovich
-*
-*                        About WebsiteBaker
-*
 * Website Baker is a PHP-based Content Management System (CMS)
 * designed with one goal in mind: to enable its users to produce websites
 * with ease.
 *
-*****************************************************************************
+*                       LICENSE INFORMATION
 *
-*****************************************************************************
-*                        LICENSE INFORMATION
-*
 * WebsiteBaker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
@@ -36,27 +22,27 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-****************************************************************************
 *
 *                   WebsiteBaker Extra Information
 *
 *
-*
-*
-*****************************************************************************/
+*/
 /**
  *
  * @category     modules
  * @package      fckeditor
  * @author       Ryan Djurovich
  * @copyright    2004-2009, Ryan Djurovich
  * @copyright    2009-2010, Website Baker Org. e.V.
  * @version      $Id$
  * @platform     WebsiteBaker 2.8.x
  * @requirements >= PHP 4.3.4
  * @license      http://www.gnu.org/licenses/gpl.html
  *
- */
+*/
 
 function reverse_htmlentities($mixed) {
 	$mixed = str_replace(array('&gt;','&lt;','&quot;','&amp;'), array('>','<','"','&'), $mixed);

Property changes on: branches/2.8.x/wb/modules/fckeditor/include.php
___________________________________________________________________
Modified: svn:keywords
## -1 +1,4 ##
-Id
\ No newline at end of property
+Id
+Revision
+HeadURL
+Date
\ No newline at end of property
@@ -36,27 +22,27 @@
 /**
  *
- * @category     modules
- * @package      fckeditor
- * @author       Ryan Djurovich
- * @copyright    2004-2009, Ryan Djurovich
- * @copyright    2009-2010, Website Baker Org. e.V.
- * @version      $Id$
- * @platform     WebsiteBaker 2.8.x
- * @requirements >= PHP 4.3.4
- * @license      http://www.gnu.org/licenses/gpl.html
+ * @category        modules
+ * @package         fckeditor
+ * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
+ * @copyright       2009-2010, Website Baker Org. e.V.
+ * @link			http://www.websitebaker2.org/
+ * @license         http://www.gnu.org/licenses/gpl.html
+ * @platform        WebsiteBaker 2.8.x
+ * @requirements    PHP 4.3.4 and higher
+ * @version         $Id$
+ * @filesource		$HeadURL$
+ * @lastmodified    $Date$
  *